@@ -1,5 +1,5 @@
 import json
-import pickle
+import pickle  # nosec:B403
 from typing import Any
 
 
@@ -30,4 +30,4 @@ class PickleCoder(Coder):
 
     @classmethod
     def decode(cls, value: Any):
-        return pickle.loads(value)
+        return pickle.loads(value)  # nosec:B403
